@@ -5,8 +5,8 @@ import shlex
 import subprocess
 import urllib.parse
 
-from yt_dlp.extractor.youtube.jsc._builtin.runtime import (
-    JsRuntimeChalBaseJCP,
+from yt_dlp.extractor.youtube.jsc._builtin.ejs import (
+    EJSBaseJCP,
     Script,
     ScriptSource,
     ScriptType,
@@ -16,7 +16,6 @@ from yt_dlp.extractor.youtube.jsc._builtin.vendor import load_script
 from yt_dlp.extractor.youtube.jsc.provider import (
     JsChallengeProvider,
     JsChallengeProviderError,
-    JsChallengeProviderRejectedRequest,
     JsChallengeRequest,
     register_preference,
     register_provider,
@@ -36,7 +35,7 @@ from yt_dlp.utils.networking import HTTPHeaderDict, clean_proxies
 
 
 @register_provider
-class BunJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
+class BunJCP(EJSBaseJCP, BuiltinIEContentProvider):
     PROVIDER_NAME = 'bun'
     JS_RUNTIME_NAME = 'bun'
     BUN_NPM_LIB_FILENAME = 'yt.solver.bun.lib.js'
@@ -58,6 +57,15 @@ class BunJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
             self._report_remote_component_skipped('ejs:npm', 'NPM package')
             return None
 
+        # Check to see if the environment proxies are compatible with Bun npm source
+        if unsupported_scheme := self._check_env_proxies(self._get_env_options()):
+            self.logger.warning(
+                f'Bun NPM package downloads only support HTTP/HTTPS proxies; skipping remote NPM package downloads. '
+                f'Provide another distribution of the challenge solver script or use '
+                f'another JS runtime that supports "{unsupported_scheme}" proxies. '
+                f'For more information and alternatives, refer to  {self.ie._EJS_WIKI_URL}')
+            return None
+
         # Bun-specific lib scripts that uses Bun autoimport
         # https://bun.com/docs/runtime/autoimport
         error_hook = lambda e: self.logger.warning(
@@ -68,6 +76,17 @@ class BunJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
             return Script(script_type, ScriptVariant.BUN_NPM, ScriptSource.BUILTIN, self._SCRIPT_VERSION, code)
         return None
 
+    def _check_env_proxies(self, env):
+        # check that the schemes of both HTTP_PROXY and HTTPS_PROXY are supported
+        for key in ('HTTP_PROXY', 'HTTPS_PROXY'):
+            proxy = env.get(key)
+            if not proxy:
+                continue
+            scheme = urllib.parse.urlparse(proxy).scheme.lower()
+            if scheme not in self.SUPPORTED_PROXY_SCHEMES:
+                return scheme
+        return None
+
     def _get_env_options(self) -> dict[str, str]:
         options = os.environ.copy()  # pass through existing bun env vars
         request_proxies = self.ie._downloader.proxies.copy()
@@ -80,24 +99,6 @@ class BunJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
             val = request_proxies.get(key)
             if val is not None:
                 options[env] = val
-
-        # check that the schemes of both HTTP_PROXY and HTTPS_PROXY are supported
-        for env in ('HTTP_PROXY', 'HTTPS_PROXY'):
-            proxy = options.get(env)
-            if not proxy:
-                continue
-            scheme = urllib.parse.urlparse(proxy).scheme.lower()
-            if scheme not in self.SUPPORTED_PROXY_SCHEMES:
-                scheme = urllib.parse.urlparse(proxy).scheme.lower()
-                self.logger.warning(
-                    f'Bun NPM requests only support HTTP/HTTPS proxies; skipping provider. '
-                    f'Provide another distribution of the challenge solver script or use '
-                    f'another JS runtime that supports "{scheme}" proxies (e.g. deno). '
-                    f'For more information, refer to  {self.ie._EJS_WIKI_URL}')
-                raise JsChallengeProviderRejectedRequest(
-                    f'External requests by "{self.PROVIDER_NAME}" provider do not '
-                    f'support proxy scheme "{scheme}". Supported proxy schemes: '
-                    f'{", ".join(self.SUPPORTED_PROXY_SCHEMES)}.')
         if self.ie.get_param('nocheckcertificate'):
             options['NODE_TLS_REJECT_UNAUTHORIZED'] = '0'
         return options
