@@ -5,8 +5,8 @@ import re
 import shlex
 import subprocess
 
-from yt_dlp.extractor.youtube.jsc._builtin.runtime import (
-    JsRuntimeChalBaseJCP,
+from yt_dlp.extractor.youtube.jsc._builtin.ejs import (
+    EJSBaseJCP,
     Script,
     ScriptSource,
     ScriptType,
@@ -27,7 +27,7 @@ from yt_dlp.utils.networking import HTTPHeaderDict, clean_proxies
 
 
 @register_provider
-class DenoJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
+class DenoJCP(EJSBaseJCP, BuiltinIEContentProvider):
     PROVIDER_NAME = 'deno'
     JS_RUNTIME_NAME = 'deno'
 
@@ -36,10 +36,8 @@ class DenoJCP(JsRuntimeChalBaseJCP, BuiltinIEContentProvider):
     _NPM_PACKAGES_CACHED = False
 
     def _iter_script_sources(self):
-        for source, func in super()._iter_script_sources():
-            if source == ScriptSource.WEB:
-                yield ScriptSource.BUILTIN, self._deno_npm_source
-            yield source, func
+        yield from super()._iter_script_sources()
+        yield ScriptSource.BUILTIN, self._deno_npm_source
 
     def _deno_npm_source(self, script_type: ScriptType, /) -> Script | None:
         if script_type != ScriptType.LIB:
